/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License") you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code in this file was released April 1, 2001
 * 
 * The Initial Developer of the Original Code is Henk-Johan van Rantwijk.
 * all Portions created by Henk-Johan van Rantwijk are Copyright (C) 2001
 * by Henk-Johan van Rantwijk. All Rights Reserved.
 * 
 * Contributor(s):
 *   Henk-Johan van Rantwijk <bugs4hj@netscape.net> (Original Author)
 *   David Perry <d.perry@utoronto.ca>
 *   Neil Pryde <NeilPryde92651@netscape.net> (well I'm just HJ's typewriter)
 * 
 */

////////////////////////////////////////////////////////////////////////////////
// Javascript functions used to handle the UI for the MultiZilla extension
// Current version : 1.1.13
// Written by : (HJ) Henk-Johan van Rantwijk <bugs4hj@netscape.net>
////////////////////////////////////////////////////////////////////////////////

// WARNING: CHANGE THIS WHEN MOVING FILES - strings localization file!
var multiviewsBundle = "chrome://multiviews/locale/multiviews.properties";
////////////////////////////////////////////////////////////////////////////////
//  custom PrefListener for MultiZilla
////////////////////////////////////////////////////////////////////////////////
const gTabWidthPrefListener =
{
  domain: "multizilla.tabs.tabwidth",
  observe: function(subject, topic, prefName)
  {
    // verify that we're changing the tab width pref
    if (topic != "nsPref:changed")
      return;

    var tabWidth = pref.getIntPref(prefName);
    gBrowser.setTabWidthTo(tabWidth);
  }
};
////////////////////////////////////////////////////////////////////////////////
//  custom PrefListener for MultiZilla
////////////////////////////////////////////////////////////////////////////////
const gTabLEDstatePrefListener =
{
  domain: "multizilla.tabs.status-leds",
  observe: function(subject, topic, prefName)
  {
    // verify that we're changing the tab width pref
    if (topic != "nsPref:changed")
      return;

    var tabLEDstate = pref.getBoolPref(prefName);
    gBrowser.setTabLEDstateTo(tabLEDstate);
  }
};
////////////////////////////////////////////////////////////////////////////////
//  custom PrefListener for MultiZilla
////////////////////////////////////////////////////////////////////////////////
const gTabLabelPrefListener =
{
  domain: "multizilla.tabs.title",
  observe: function(subject, topic, prefName)
  {
    // verify that we're changing the tab title pref
    if (topic != "nsPref:changed")
      return;

    var tabLabel = pref.getBoolPref(prefName);
    gBrowser.setTabLabelsTo(tabLabel);
  }
};
////////////////////////////////////////////////////////////////////////////////
//  custom PrefListener for MultiZilla
////////////////////////////////////////////////////////////////////////////////
const gTabSwitchPrefListener =
{
  domain: "multizilla.tabs.ontop",
  observe: function(subject, topic, prefName)
  {
    // verify that we're changing the tab title pref
    if (topic != "nsPref:changed")
      return;

    var topTabs = pref.getBoolPref(prefName);
    if (topTabs)
      gBrowser.activateTopTabs()
    else gBrowser.activateBottomTabs();
  }
};
////////////////////////////////////////////////////////////////////////////////
//  this is our Tab DND observer
////////////////////////////////////////////////////////////////////////////////
var tabDNDObserver = {

  onDragStart: function (aEvent, aXferData, aDragAction)
    {
      if (navigator.platform != "Win32" || aEvent.target.localName != "tab" || 
          aEvent.target != gBrowser.mCurrentTab )
        return;
      var url = getWebNavigation().currentURI.spec;
      aXferData.data = new TransferData();
      aXferData.data.addDataForFlavour( "text/x-moz-url", url );
    },
  onDragOver: function( aEvent, aFlavour, aDragSession )
    {
      getBrowser().selectedTab = aEvent.target;
      aEvent.target.setAttribute( "dragover", "true" );
      return true;
    },
  onDragExit: function ( aEvent, aDragSession )
    {
      aEvent.target.removeAttribute( "dragover" );
    },
  onDrop: function ( aEvent, aXferData, aDragSession )
    {
      var url = retrieveURLFromData( aXferData.data, aXferData.flavour.contentType );
      if ( url )
        loadURI( url );
    },
  getSupportedFlavours: function ()
    {
      var flavourSet = new FlavourSet();
      flavourSet.appendFlavour( "application/x-moz-file", "nsIFile" );
      flavourSet.appendFlavour( "text/x-moz-url" );
      flavourSet.appendFlavour( "text/unicode" );
      return flavourSet;
    }
}
////////////////////////////////////////////////////////////////////////////////
// this function asks the user to confirm to quit the session
////////////////////////////////////////////////////////////////////////////////
function confirmCloseWS( aConfirm )
{
  var confirmPref = readMyPref( "multizilla.confirm.quit", "int", 0 );
  var closeBundle = srGetStrBundle( "chrome://multiviews/locale/multiviews.properties" );
  var aHeader = closeBundle.GetStringFromName( "closeSession" );
  var aQuestion = closeBundle.GetStringFromName( "closeSessionQuestion" );
  /* ::::
     1 = File Menu 'Close Window' & Ctrl-Shift-W
     2 = File Menu 'Exit' & Ctrl-Q
     4 = Click on [X] on Window
  :::: */
  if ( aConfirm & 1 ) {
    aHeader = closeBundle.GetStringFromName( "closeWindow" );
    aQuestion = closeBundle.GetStringFromName( "closeWindowQuestion" );
  }
  if ( confirmPref && (confirmPref & aConfirm) == aConfirm ) {
    var promptService = Components.classes[ "@mozilla.org/embedcomp/prompt-service;1" ].
                        getService(Components.interfaces.nsIPromptService);

    if ( promptService.confirm( window, aHeader, aQuestion ) )
      return true;
    else
      return false;
  }
  else return true;
}
////////////////////////////////////////////////////////////////////////////////
// this function initializes MultiZilla
////////////////////////////////////////////////////////////////////////////////
function multiZillaInit()
{
  addPrefListener(gTabWidthPrefListener);
  addPrefListener(gTabLEDstatePrefListener);
  addPrefListener(gTabLabelPrefListener);
  addPrefListener(gTabSwitchPrefListener);

  var toolbar = document.getElementById("navigator-toolbox");
  var newElement = document.createElement("tabmodetoolbar");

  toolbar = toolbar.appendChild(newElement);
  toolbar.setAttribute("id", "MultiZillaToolbar");
  initPreferences();
}
////////////////////////////////////////////////////////////////////////////////
// this function initializes MultiZilla
////////////////////////////////////////////////////////////////////////////////
function addGoMenuIDs()
{
  var goMenu = document.getElementById("main-menubar").childNodes[3];
  goMenu.setAttribute("id", "menu_Go");
  var goMenuPopup = document.getElementById("menu_GoPopup");
  goMenu.firstChild.setAttribute("id", "menu_GoPopup");
  goMenu.replaceChild(goMenuPopup, goMenu.firstChild);
}